@@ -1,3 +1,4 @@
+
 import sys
 import os
 from layout import *
@@ -10,7 +11,7 @@ for args in arguments:
 
  elif args=="--about" or args=="-a":
   print("""\033[34;1;40mThis program is made by Devesh Sharma using the tkinter who lives in Panipat , Haryana located in India. He wants to provide a best coding experiences using python modules and makimg efforts to enhance its performance and this program is freely available on github Anybody who want to support is free to support in this program and anybody who wants to use this program can use this program in his programs or project or for anyuses without my permission. Regards to Readers
-👋⭐🌟 Thank You  🌟⭐👋
+Thank You
 A wish to Readers by Devesh Sharma
 """)
  elif args=="--start" or args=="-s":
